# -*- coding: utf-8 -*-

from . import logger
from plone import api
from plone.app.upgrade.utils import installOrReinstallProduct


def upgrade(setup_tool=None):
    """ """
    logger.info("Install blocksfield")
    installOrReinstallProduct(api.portal.get(), "collective.volto.blocksfield")



# -*- coding: utf-8 -*-


DEFAULT_PROFILE = "profile-iosanita.contenttypes:default"


def upgrade(context):
    """ """
    context.runImportStepFromProfile(
        DEFAULT_PROFILE, "plone.app.registry", run_dependencies=False
    )



# -*- coding: utf-8 -*-

from . import logger
from plone import api
from plone.app.upgrade.utils import loadMigrationProfile


def upgrade(setup_tool=None):
    """ """
    logger.info("Running upgrade (Python): Add Subject_bando index")
    loadMigrationProfile(api.portal.get(), "iosanita.contenttypes.upgrades:1005")

    brains = api.content.find(portal_type="Bando")
    i = 0
    tot = len(brains)
    logger.info("### START CONVERSION FIELDS RICHTEXT -> DRAFTJS ###")
    for brain in brains:
        i += 1
        if i % 100 == 0:
            logger.info(f"Progress: {i}/{tot}")
        obj = brain.getObject()
        obj.reindexObject(idxs=["Subject_bando"])



# -*- coding: utf-8 -*-
from plone import api


def upgrade(setup_tool=None):
    """ """
    portal_types = api.portal.get_tool(name="portal_types")

    behaviors = portal_types["Plone Site"].behaviors
    if "kitconcept.seo" not in behaviors:
        behaviors = list(behaviors)
        behaviors.append("kitconcept.seo")
        portal_types["Plone Site"].behaviors = tuple(behaviors)
